@@ -1,29 +1,17 @@
-/* This file is part of the KDE project
-   Copyright (C) 1999 Simon Hausmann <hausmann@kde.org>
-             (C) 1999-2005 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1999 Simon Hausmann <hausmann@kde.org>
+    SPDX-FileCopyrightText: 1999-2005 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef _KPARTS_READONLYPART_P_H
 #define _KPARTS_READONLYPART_P_H
 
+#include "openurlarguments.h"
 #include "part_p.h"
 #include "readonlypart.h"
-#include "openurlarguments.h"
 
 namespace KIO
 {
@@ -33,13 +21,13 @@ class StatJob;
 
 namespace KParts
 {
-
-class ReadOnlyPartPrivate: public PartPrivate
+class ReadOnlyPartPrivate : public PartPrivate
 {
 public:
     Q_DECLARE_PUBLIC(ReadOnlyPart)
 
-    ReadOnlyPartPrivate(ReadOnlyPart *q): PartPrivate(q)
+    explicit ReadOnlyPartPrivate(ReadOnlyPart *q)
+        : PartPrivate(q)
     {
         m_job = nullptr;
         m_statJob = nullptr;
@@ -57,9 +45,9 @@ public:
     {
     }
 
-    void _k_slotJobFinished(KJob *job);
-    void _k_slotStatJobFinished(KJob *job);
-    void _k_slotGotMimeType(KIO::Job *job, const QString &mime);
+    void slotJobFinished(KJob *job);
+    void slotStatJobFinished(KJob *job);
+    void slotGotMimeType(KIO::Job *job, const QString &mime);
     bool openLocalFile();
     void openRemoteFile();
 
@@ -76,7 +64,7 @@ public:
     /**
      * If @p true, @p m_file is a temporary file that needs to be deleted later.
      */
-    bool m_bTemp: 1;
+    bool m_bTemp : 1;
 
     // whether the mimetype in the arguments was detected by the part itself
     bool m_bAutoDetectedMime : 1;
